function [visc,status] = DWRLowerAndUpperPhase_Shear(Beginviscositeit,Softwaretorque,Viscositylower,Viscosityupper,Angularvelocity,handles)

% Matlab code om data van double wall ring te corrigeren voor
% subfase-contributies. Enkel met lower phase.

% Here you need to give in all you datapoints
tic

format long g
% Beginviscositeit=[1e-5];
% Softwaretorque=[.7874208225e-8];
% density=1000;
% viscositylower=0.001;
% viscosityupper=0.00092;
% angularvelocity=[1];

% parameters that remain constant, DON'T CHANGE

J=18;
JJ=22;
S=16;
SS=20;
K=40;
KK=35;
maxaantaliteratiestappen=30;
rinterval=0.0045/18;
zinterval=0.01/40;
convergentie=0;
status=1;

ax=K+1;
aax=KK+1;
ay=J+1;
aay=JJ+1;
bx=K+1;
bbx=KK+1;
by=S+1;
bby=SS+1;

for v=1:length(Beginviscositeit)            % run over all datapoints
    
    pause(3)
    set(handles.convergentietext,'String','No');
    c=num2str(v);
    set(handles.datapoint,'String',c);
    pause(2)
    softwaretorque=Softwaretorque(v);
    Viscositeit(v)=Beginviscositeit(v);
    viscositylower=Viscositylower(v);
    viscosityupper=Viscosityupper(v);
    angularvelocity=Angularvelocity(v);
    
    w=1;
    status(v)=1;
    convergentie=0;
    
    while convergentie==0          % Iteration
        
        A = eye(ax*ay+bx*by+aax*aay+bbx*bby);
        b = zeros(ax*ay+bx*by+aax*aay+bbx*bby,1);
        
        % Boundary conditions        
        
        b(1)=0.035*angularvelocity;
        b(2)=0.035*angularvelocity;
        b(3)=0.035*angularvelocity;
        b(ax+1)=0.03525*angularvelocity;
        b(2*ax+1)=0.0355*angularvelocity;
        b(ax+2)=0.03525*angularvelocity;
        
        b(ax*ay+16*bx+1)=0.035*angularvelocity;
        b(ax*ay+16*bx+2)=0.035*angularvelocity;
        b(ax*ay+16*bx+3)=0.035*angularvelocity;
        b(ax*ay+15*bx+1)=0.03475*angularvelocity;
        b(ax*ay+14*bx+1)=0.0345*angularvelocity;
        b(ax*ay+15*bx+2)=0.03475*angularvelocity;
        
        b(ax*ay+bx*by+1)=0.035*angularvelocity;
        b(ax*ay+bx*by+aax*aay+1+20*bbx)=0.035*angularvelocity;
        b(ax*ay+bx*by+2)=0.035*angularvelocity;
        b(ax*ay+bx*by+aax*aay+2+20*bbx)=0.035*angularvelocity;
        b(ax*ay+bx*by+3)=0.035*angularvelocity;
        b(ax*ay+bx*by+aax*aay+3+20*bbx)=0.035*angularvelocity;
        b(ax*ay+bx*by+1+aax)=0.03525*angularvelocity;
        b(ax*ay+bx*by+aax*aay+1+19*bbx)=0.03475*angularvelocity;
        b(ax*ay+bx*by+1+2*aax)=0.0355*angularvelocity;
        b(ax*ay+bx*by+aax*aay+1+18*bbx)=0.0345*angularvelocity;
        b(ax*ay+bx*by+2+1*aax)=0.03525*angularvelocity;
        b(ax*ay+bx*by+aax*aay+2+19*bbx)=0.03475*angularvelocity;
        
        
        b(J*ax+1:J*ax+ax)=0;
        b(ax*ay+1:ax*ay+bx)=0;
        
        b(ax:ax:ax*ay)=0;
        b(ax*ay+bx:bx:ax*ay+bx*by)=0;
        
        b(ax*ay+bx*by+JJ*aax+1:ax*ay+bx*by+JJ*aax+KK+1)=0;
        b(ax+ay+bx*by+aax*aay+1:ax+ay+bx*by+aax*aay+KK+1)=0;
        b(ax*ay+bx*by+KK+1:aax:ax*ay+bx*by+KK+1+JJ*aax)=0;
        b(ax+ay+bx*by+aax*aay+KK+1:bbx:ax+ay+bx*by+aax*aay+KK+1+SS*bbx)=0;
        b(ax*ay+bx*by+1+21*aax)=0;
        b(ax*ay+bx*by+1+20*aax)=0;
        b(ax*ay+bx*by+1+19*aax)=0;
        b(ax*ay+bx*by+aax*aay+1+1*bbx)=0;
        b(ax*ay+bx*by+aax*aay+1+2*bbx)=0;
        b(ax*ay+bx*by+aax*aay+1+3*bbx)=0;
        
               
        % Equations
        
        
        % for w to 5 do for p from 3 to J do eqn[w][2,p] := 
        % 0 = viscosity*(1/(.35e-1+(p-1)*rinterval)*(a[w][2,p+1]-a[w][2,p-1])/(2*rinterval)-a[w][2,p]/((.35e-1+(p-1)*rinterval)^2)+
        % (a[w][2,p+1]-2*a[w][2,p]+a[w][2,p-1])/(rinterval^2)+(a[w][3,p]-2*a[w][2,p]+a[w][1,p])/(zinterval^2)) end do end do;
          
        for p=3:J
            
            A((p-1)*ax+2,(p-1)*ax+2)=-1/((.35e-1+(p-1)*rinterval)^2)-2/(rinterval^2)-2/(zinterval^2);   % a[w][2,p]
            A((p-1)*ax+2,(p)*ax+2)=1/(.35e-1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);                     % a[w][2,p+1]
            A((p-1)*ax+2,(p-2)*ax+2)=-1/(.35e-1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);                  % a[w][2,p-1]
            A((p-1)*ax+2,(p-1)*ax+3)=1/(zinterval^2);                        % a[w][3,p]
            A((p-1)*ax+2,(p-1)*ax+1)=1/(zinterval^2);                        % a[w][1,p]
        end
        
        
        
        % for pp from 3 to JJ do eqneqn[2,pp] := 0 =
        % viscosityupper*(1/(.35e-1+(pp-1)*rinterval)*(aa[2,pp+1]-aa[2,pp-1])/(2*rinterval)-aa[2,pp]/((.35e-1+(pp-1)*rinterval)^2)+
        % (aa[2,pp+1]-2*aa[2,pp]+aa[2,pp-1])/(rinterval^2)+(aa[3,pp]-2*aa[2,pp]+aa[1,pp])/(zinterval^2)) end do;
        
        for p=3:JJ
            
            A(ax*ay+bx*by+(p-1)*aax+2,ax*ay+bx*by+(p-1)*aax+2)=-1/((.35e-1+(p-1)*rinterval)^2)-2/(rinterval^2)-2/(zinterval^2);   % aa[w][2,p]
            A(ax*ay+bx*by+(p-1)*aax+2,ax*ay+bx*by+(p)*aax+2)=1/(.35e-1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);                     % aa[w][2,p+1]
            A(ax*ay+bx*by+(p-1)*aax+2,ax*ay+bx*by+(p-2)*aax+2)=-1/(.35e-1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);                  % aa[w][2,p-1]
            A(ax*ay+bx*by+(p-1)*aax+2,ax*ay+bx*by+(p-1)*aax+3)=1/(zinterval^2);                        % aa[w][3,p]
            A(ax*ay+bx*by+(p-1)*aax+2,ax*ay+bx*by+(p-1)*aax+1)=1/(zinterval^2);                        % aa[w][1,p]
        end 
        
            
        % for w to 5 do for p from 2 to S-1 do eqnn[w][2,p] := 
        % 0 = viscosity*(1/(.31e-1+(p-1)*rinterval)*(b[w][2,p+1]-b[w][2,p-1])/(2*rinterval)-b[w][2,p]/((.31e-1+(p-1)*rinterval)^2)+
        % (b[w][2,p+1]-2*b[w][2,p]+b[w][2,p-1])/(rinterval^2)+(b[w][3,p]-2*b[w][2,p]+b[w][1,p])/(zinterval^2)) end do end do;

        for p=2:S-1
            
            A(ax*ay+(p-1)*bx+2,ax*ay+(p-1)*bx+2)=-1/((.31e-1+(p-1)*rinterval)^2)-2/(rinterval^2)-2/(zinterval^2);% b[w][2,p]
            A(ax*ay+(p-1)*bx+2,ax*ay+(p)*bx+2)=1/(.31e-1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);     % b[w][2,p+1]
            A(ax*ay+(p-1)*bx+2,ax*ay+(p-2)*bx+2)=-1/(.31e-1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);     % b[w][2,p-1]
            A(ax*ay+(p-1)*bx+2,ax*ay+(p-1)*bx+3)=1/(zinterval^2); % b[w][3,p]
            A(ax*ay+(p-1)*bx+2,ax*ay+(p-1)*bx+1)=1/(zinterval^2); % b[w][1,p]
        end   
        
        % for pp from 2 to SS-1 do eqnneqnn[2,pp] := 0 = 
        % viscosityupper*(1/(.3e-1+(pp-1)*rinterval)*(bb[2,pp+1]-bb[2,pp-1])/(2*rinterval)-bb[2,pp]/((.3e-1+(pp-1)*rinterval)^2)+
        % (bb[2,pp+1]-2*bb[2,pp]+bb[2,pp-1])/(rinterval^2)+(bb[3,pp]-2*bb[2,pp]+bb[1,pp])/(zinterval^2)) end do;
        
        for p=2:SS-1
            
            A(ax*ay+bx*by+aax*aay+(p-1)*bbx+2,ax*ay+bx*by+aax*aay+(p-1)*bbx+2)=-1/((.3e-1+(p-1)*rinterval)^2)-2/(rinterval^2)-2/(zinterval^2);% bb[w][2,p]
            A(ax*ay+bx*by+aax*aay+(p-1)*bbx+2,ax*ay+bx*by+aax*aay+(p)*bbx+2)=1/(.3e-1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);     % bb[w][2,p+1]
            A(ax*ay+bx*by+aax*aay+(p-1)*bbx+2,ax*ay+bx*by+aax*aay+(p-2)*bbx+2)=-1/(.3e-1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);     % bb[w][2,p-1]
            A(ax*ay+bx*by+aax*aay+(p-1)*bbx+2,ax*ay+bx*by+aax*aay+(p-1)*bbx+3)=1/(zinterval^2); % bb[w][3,p]
            A(ax*ay+bx*by+aax*aay+(p-1)*bbx+2,ax*ay+bx*by+aax*aay+(p-1)*bbx+1)=1/(zinterval^2); % bb[w][1,p]
        end   
        

        % for w from 1 to 5 do for p from 2 to J do eqn[w][3,p] := 
        % 0 = viscosity*(1/(.35e-1+(p-1)*rinterval)*(a[w][3,p+1]-a[w][3,p-1])/(2*rinterval)-a[w][3,p]/((.35e-1+(p-1)*rinterval)^2)+
        % (a[w][3,p+1]-2*a[w][3,p]+a[w][3,p-1])/(rinterval^2)+(a[w][4,p]-2*a[w][3,p]+a[w][2,p])/(zinterval^2)) end do end do;

        for p=2:J
            
            A((p-1)*ax+3,(p-1)*ax+2+1)=-1/((.35e-1+(p-1)*rinterval)^2)-2/(rinterval^2)-2/(zinterval^2);% a[w][3,p]
            A((p-1)*ax+3,(p)*ax+2+1)=1/(.35e-1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);   % a[w][3,p+1]
            A((p-1)*ax+3,(p-2)*ax+2+1)=-1/(.35e-1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2); % a[w][3,p-1]
            A((p-1)*ax+3,(p-1)*ax+3+1)=1/(zinterval^2);% a[w][4,p]
            A((p-1)*ax+3,(p-1)*ax+1+1)=1/(zinterval^2);% a[w][2,p]
        end
        
        % for pp from 2 to JJ do eqneqn[3,pp] := 0 =
        % viscosityupper*(1/(.35e-1+(pp-1)*rinterval)*(aa[3,pp+1]-aa[3,pp-1])/(2*rinterval)-aa[3,pp]/((.35e-1+(pp-1)*rinterval)^2)+
        % (aa[3,pp+1]-2*aa[3,pp]+aa[3,pp-1])/(rinterval^2)+(aa[4,pp]-2*aa[3,pp]+aa[2,pp])/(zinterval^2)) end do;
        
        for p=2:JJ
            
            A(ax*ay+bx*by+(p-1)*aax+3,ax*ay+bx*by+(p-1)*aax+2+1)=-1/((.35e-1+(p-1)*rinterval)^2)-2/(rinterval^2)-2/(zinterval^2);% aa[w][3,p]
            A(ax*ay+bx*by+(p-1)*aax+3,ax*ay+bx*by+(p)*aax+2+1)=1/(.35e-1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);   % aa[w][3,p+1]
            A(ax*ay+bx*by+(p-1)*aax+3,ax*ay+bx*by+(p-2)*aax+2+1)=-1/(.35e-1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2); % aa[w][3,p-1]
            A(ax*ay+bx*by+(p-1)*aax+3,ax*ay+bx*by+(p-1)*aax+3+1)=1/(zinterval^2);% aa[w][4,p]
            A(ax*ay+bx*by+(p-1)*aax+3,ax*ay+bx*by+(p-1)*aax+1+1)=1/(zinterval^2);% aa[w][2,p]
        end
  
        % for w to 5 do for p from 2 to S do eqnn[w][3,p] := 
        % 0 = viscosity*(1/(.31e-1+(p-1)*rinterval)*(b[w][3,p+1]-b[w][3,p-1])/(2*rinterval)-b[w][3,p]/((.31e-1+(p-1)*rinterval)^2)+
        % (b[w][3,p+1]-2*b[w][3,p]+b[w][3,p-1])/(rinterval^2)+(b[w][4,p]-2*b[w][3,p]+b[w][2,p])/(zinterval^2)) end do end do;
       
        for p=2:S
            
            A(ax*ay+(p-1)*bx+3,ax*ay+(p-1)*bx+2+1)=-1/((.31e-1+(p-1)*rinterval)^2)-2/(rinterval^2)-2/(zinterval^2);% b[w][3,p]
            A(ax*ay+(p-1)*bx+3,ax*ay+(p)*bx+2+1)=1/(.31e-1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);     % b[w][3,p+1]
            A(ax*ay+(p-1)*bx+3,ax*ay+(p-2)*bx+2+1)=-1/(.31e-1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);     % b[w][3,p-1]
            A(ax*ay+(p-1)*bx+3,ax*ay+(p-1)*bx+3+1)=1/(zinterval^2); % b[w][4,p]
            A(ax*ay+(p-1)*bx+3,ax*ay+(p-1)*bx+1+1)=1/(zinterval^2); % b[w][1,p]
        end   
        
        % for pp from 2 to SS do eqnneqnn[3,pp] := 0 =
        % viscosityupper*(1/(.3e-1+(pp-1)*rinterval)*(bb[3,pp+1]-bb[3,pp-1])/(2*rinterval)-bb[3,pp]/((.3e-1+(pp-1)*rinterval)^2)+
        % (bb[3,pp+1]-2*bb[3,pp]+bb[3,pp-1])/(rinterval^2)+(bb[4,pp]-2*bb[3,pp]+bb[2,pp])/(zinterval^2)) end do;
        
        for p=2:SS
            
            A(ax*ay+bx*by+aax*aay+(p-1)*bbx+3,ax*ay+bx*by+aax*aay+(p-1)*bbx+2+1)=-1/((.3e-1+(p-1)*rinterval)^2)-2/(rinterval^2)-2/(zinterval^2);% bb[w][3,p]
            A(ax*ay+bx*by+aax*aay+(p-1)*bbx+3,ax*ay+bx*by+aax*aay+(p)*bbx+2+1)=1/(.3e-1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);     % bb[w][3,p+1]
            A(ax*ay+bx*by+aax*aay+(p-1)*bbx+3,ax*ay+bx*by+aax*aay+(p-2)*bbx+2+1)=-1/(.3e-1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);     % bb[w][3,p-1]
            A(ax*ay+bx*by+aax*aay+(p-1)*bbx+3,ax*ay+bx*by+aax*aay+(p-1)*bbx+3+1)=1/(zinterval^2); % bb[w][4,p]
            A(ax*ay+bx*by+aax*aay+(p-1)*bbx+3,ax*ay+bx*by+aax*aay+(p-1)*bbx+1+1)=1/(zinterval^2); % bb[w][1,p]
        end   
        

        % for w from 1 to 5 do for p from 2 to J do for m from 4 to K do
        % eqn[w][m,p] := 0 = viscosity*(1/(.35e-1+(p-1)*rinterval)*(a[w][m,p+1]-a[w][m,p-1])/(2*rinterval)-a[w][m,p]/((.35e-1+(p-1)*rinterval)^2)+
        % (a[w][m,p+1]-2*a[w][m,p]+a[w][m,p-1])/(rinterval^2)+(a[w][m+1,p]-2*a[w][m,p]+a[w][m-1,p])/(zinterval^2))end do end do end do;

        for p=2:J
            
            for m=4:K
                
                A((p-1)*ax+m,(p-1)*ax+m)=-1/((.35e-1+(p-1)*rinterval)^2)-2/(rinterval^2)-2/(zinterval^2);   % a[w][m,p]
                A((p-1)*ax+m,(p)*ax+m)=1/(.35e-1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);                     % a[w][m,p+1]
                A((p-1)*ax+m,(p-2)*ax+m)=-1/(.35e-1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);                  % a[w][m,p-1]
                A((p-1)*ax+m,(p-1)*ax+m+1)=1/(zinterval^2);                        % a[w][m+1,p]
                A((p-1)*ax+m,(p-1)*ax+m-1)=1/(zinterval^2);                        % a[w][m-1,p]
            end
        end
        
        % for pp from 2 to JJ do for mm from 4 to KK do 
        % eqneqn[mm,pp] := 0= viscosityupper*(1/(.35e-1+(pp-1)*rinterval)*(aa[mm,pp+1]-aa[mm,pp-1])/(2*rinterval)-aa[mm,pp]/((.35e-1+(pp-1)*rinterval)^2)+
        % (aa[mm,pp+1]-2*aa[mm,pp]+aa[mm,pp-1])/(rinterval^2)+(aa[mm+1,pp]-2*aa[mm,pp]+aa[mm-1,pp])/(zinterval^2)) end do end do;
        
        for p=2:JJ
            
            for m=4:KK
                
                A(ax*ay+bx*by+(p-1)*aax+m,ax*ay+bx*by+(p-1)*aax+m)=-1/((.35e-1+(p-1)*rinterval)^2)-2/(rinterval^2)-2/(zinterval^2);   % aa[w][m,p]
                A(ax*ay+bx*by+(p-1)*aax+m,ax*ay+bx*by+(p)*aax+m)=1/(.35e-1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);                     % aa[w][m,p+1]
                A(ax*ay+bx*by+(p-1)*aax+m,ax*ay+bx*by+(p-2)*aax+m)=-1/(.35e-1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);                  % aa[w][m,p-1]
                A(ax*ay+bx*by+(p-1)*aax+m,ax*ay+bx*by+(p-1)*aax+m+1)=1/(zinterval^2);                        % aa[w][m+1,p]
                A(ax*ay+bx*by+(p-1)*aax+m,ax*ay+bx*by+(p-1)*aax+m-1)=1/(zinterval^2);                        % aa[w][m-1,p]
            end
        end
        
        % for w to 5 do for p from 2 to S do for m from 4 to K do
        % eqnn[w][m,p] := 0 = viscosity*(1/(.31e-1+(p-1)*rinterval)*(b[w][m,p+1]-b[w][m,p-1])/(2*rinterval)-b[w][m,p]/((.31e-1+(p-1)*rinterval)^2)+
        % (b[w][m,p+1]-2*b[w][m,p]+b[w][m,p-1])/(rinterval^2)+(b[w][m+1,p]-2*b[w][m,p]+b[w][m-1,p])/(zinterval^2)) end do end do end do;
        
        
        for p=2:S
            
            for m=4:K
                
                A(ax*ay+(p-1)*bx+m,ax*ay+(p-1)*bx+m)=-1/((.31e-1+(p-1)*rinterval)^2)-2/(rinterval^2)-2/(zinterval^2);% b[w][m,p]
                A(ax*ay+(p-1)*bx+m,ax*ay+(p)*bx+m)=1/(.31e-1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);     % b[w][m,p+1]
                A(ax*ay+(p-1)*bx+m,ax*ay+(p-2)*bx+m)=-1/(.31e-1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);     % b[w][m,p-1]
                A(ax*ay+(p-1)*bx+m,ax*ay+(p-1)*bx+m+1)=1/(zinterval^2); % b[w][m+1,p]
                A(ax*ay+(p-1)*bx+m,ax*ay+(p-1)*bx+m-1)=1/(zinterval^2); % b[w][m-1,p]
            end
        end
        
        % for pp from 2 to SS do for mm from 4 to KK do eqnneqnn[mm,pp] :=
        % 0 = viscosityupper*(1/(.3e-1+(pp-1)*rinterval)*(bb[mm,pp+1]-bb[mm,pp-1])/(2*rinterval)-bb[mm,pp]/((.3e-1+(pp-1)*rinterval)^2)+
        % (bb[mm,pp+1]-2*bb[mm,pp]+bb[mm,pp-1])/(rinterval^2)+(bb[mm+1,pp]-2*bb[mm,pp]+bb[mm-1,pp])/(zinterval^2)) end do end do;

        for p=2:SS
            
            for m=4:KK
                
                A(ax*ay+bx*by+aax*aay+(p-1)*bbx+m,ax*ay+bx*by+aax*aay+(p-1)*bbx+m)=-1/((.3e-1+(p-1)*rinterval)^2)-2/(rinterval^2)-2/(zinterval^2);% b[w][m,p]
                A(ax*ay+bx*by+aax*aay+(p-1)*bbx+m,ax*ay+bx*by+aax*aay+(p)*bbx+m)=1/(.3e-1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);     % b[w][m,p+1]
                A(ax*ay+bx*by+aax*aay+(p-1)*bbx+m,ax*ay+bx*by+aax*aay+(p-2)*bbx+m)=-1/(.3e-1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);     % b[w][m,p-1]
                A(ax*ay+bx*by+aax*aay+(p-1)*bbx+m,ax*ay+bx*by+aax*aay+(p-1)*bbx+m+1)=1/(zinterval^2); % b[w][m+1,p]
                A(ax*ay+bx*by+aax*aay+(p-1)*bbx+m,ax*ay+bx*by+aax*aay+(p-1)*bbx+m-1)=1/(zinterval^2); % b[w][m-1,p]
            end
        end
        
        
        % for w from 1 to aantaliteratiestappen do for m from 4 to K do eqnnn[w][m,1] := b[w][m, 17] = a[w][m,1] end do end do; 

        for m=4:K
            
            A(ax*ay+16*bx+m,m)=1;
            A(ax*ay+16*bx+m,ax*ay+16*bx+m)=-1;
        end
        
        % for mm from 4 to KK do eqnnneqnnn[mm,1] := bb[mm,21] = aa[mm,1] end do;
        
        for m=4:KK
            
            A(ax*ay+bx*by+aax*aay+20*bbx+m,ax*ay+bx*by+m)=1;
            A(ax*ay+bx*by+aax*aay+20*bbx+m,ax*ay+bx*by+aax*aay+20*bbx+m)=-1;
        end
        
        % for w to 5 do for m from 4 to K do eqn[w][m,1] := 0 =
        % viscosity*(1/.35e-1*(a[w][m,2]-b[w][m,16])/(2*rinterval)-a[w][m,1]/(.35e-1^2)+(a[w][m,2]-2*a[w][m,1]+b[w][m,16])/(rinterval^2)+
        % (a[w][m+1,1]-2*a[w][m,1]+a[w][m-1,1])/(zinterval^2)) end do end do;
                
        for m=4:K
            
            A(m,m)=-1/(.35e-1^2)-2/(rinterval^2)-2/(zinterval^2);      % a[w][m,1]
            A(m,ax+m)=(1/(.35e-1))/(2*rinterval)+1/(rinterval^2);            % a[w][m,2]
            A(m,ax*ay+15*bx+m)=-(1/.35e-1)/(2*rinterval)+1/(rinterval^2); % b[w][m,16]
            A(m,m+1)=1/(zinterval^2);% a[w][m+1,1]
            A(m,m-1)=1/(zinterval^2);% a[w][m-1,1]
        end
        
        % for mm from 4 to KK do eqneqn[mm,1] := 0 =
        % viscosityupper*(1/.35e-1*(aa[mm,2]-bb[mm,20])/(2*rinterval)-aa[mm,1]/(.35e-1^2)+(aa[mm,2]-2*aa[mm,1]+bb[mm,20])/(rinterval^2)+
        % (aa[mm+1,1]-2*aa[mm,1]+aa[mm-1,1])/(zinterval^2)) end do;
        
        for m=4:KK
            
            A(ax*ay+bx*by+m,ax*ay+bx*by+m)=-1/(.35e-1^2)-2/(rinterval^2)-2/(zinterval^2);      % aa[w][m,1]
            A(ax*ay+bx*by+m,ax*ay+bx*by+aax+m)=(1/(.35e-1))/(2*rinterval)+1/(rinterval^2);            % aa[w][m,2]
            A(ax*ay+bx*by+m,ax*ay+bx*by+aax*aay+19*bbx+m)=-(1/.35e-1)/(2*rinterval)+1/(rinterval^2); % bb[w][m,16]
            A(ax*ay+bx*by+m,ax*ay+bx*by+m+1)=1/(zinterval^2);% aa[w][m+1,1]
            A(ax*ay+bx*by+m,ax*ay+bx*by+m-1)=1/(zinterval^2);% aa[w][m-1,1]
        end
        

        % for w to 5 do for p from 4 to J do eqn[w][1,p] :=
        % (-viscosity)*(4*a[w][2,p]-3*a[w][1,p]-a[w][3,p])/(2*zinterval) = Viscositeit[w]*(1/(.35e-1+(p-1)*rinterval)*(1*a[w][1,p+1]-a[w][1,p-1])/(2*rinterval)
        % -a[w][1,p]/((.35e-1+(p-1)*rinterval)^2)+(a[w][1,p+1]-2*a[w][1,p]+a[w][1,p-1])/(rinterval^2)) end do end do;
        
%         for p=4:J
%             
%             A((p-1)*ax+1,(p-1)*ax+1)=-3*viscosity/(2*zinterval)+(Viscositeit(v))*(-1)/((.35e-1+(p-1)*rinterval)^2)-2*(Viscositeit(v))/(rinterval^2); %a[w][1,p]
%             A((p-1)*ax+1,(p-1)*ax+2)=4*viscosity/(2*zinterval);% a[w][2,p]
%             A((p-1)*ax+1,(p-1)*ax+3)=-1*viscosity/(2*zinterval);% a[w][3,p]
%             A((p-1)*ax+1,(p)*ax+1)=(Viscositeit(v))*1/(.35e-1+(p-1)*rinterval)/(2*rinterval)+(Viscositeit(v))/(rinterval^2);% a[w][1,p+1]
%             A((p-1)*ax+1,(p-2)*ax+1)=-(Viscositeit(v))*1/(.35e-1+(p-1)*rinterval)/(2*rinterval)+(Viscositeit(v))/(rinterval^2);% a[w][1,p-1]
%         end
        
        % for p from 4 to J do eqn[1,p] :=
        % (-viscositylower)*(4*a[2,p]-3*a[1,p]-a[3,p])/(2*zinterval)+(-viscosityupper)*(4*aa[2,p]-3*aa[1,p]-aa[3,p])/(2*zinterval) = 
        % X*(1/(.35e-1+(p-1)*rinterval)*(1*a[1,p+1]-a[1,p-1])/(2*rinterval)-a[1,p]/((.35e-1+(p-1)*rinterval)^2)+(a[1,p+1]-2*a[1,p]+a[1,p-1])/(rinterval^2)) end do;
        
        for p=4:J
            
            A((p-1)*ax+1,(p-1)*ax+1)=-3*viscositylower/(2*zinterval)+(Viscositeit(v))*(-1)/((.35e-1+(p-1)*rinterval)^2)-2*(Viscositeit(v))/(rinterval^2); %a[w][1,p]
            A((p-1)*ax+1,(p-1)*ax+2)=4*viscositylower/(2*zinterval);% a[w][2,p]
            A((p-1)*ax+1,(p-1)*ax+3)=-1*viscositylower/(2*zinterval);% a[w][3,p]
            A((p-1)*ax+1,(p)*ax+1)=(Viscositeit(v))*1/(.35e-1+(p-1)*rinterval)/(2*rinterval)+(Viscositeit(v))/(rinterval^2);% a[w][1,p+1]
            A((p-1)*ax+1,(p-2)*ax+1)=-(Viscositeit(v))*1/(.35e-1+(p-1)*rinterval)/(2*rinterval)+(Viscositeit(v))/(rinterval^2);% a[w][1,p-1]
            A((p-1)*ax+1,ax*ay+bx*by+(p-1)*aax+1)=-3*viscosityupper/(2*zinterval); % aa[1,p]
            A((p-1)*ax+1,ax*ay+bx*by+(p-1)*aax+2)=4*viscosityupper/(2*zinterval); % aa[2,p]
            A((p-1)*ax+1,ax*ay+bx*by+(p-1)*aax+3)=-1*viscosityupper/(2*zinterval); % aa[3,p]
        end
        
        % for w to 5 do for p from 2 to S-2 do eqnn[w][1,p] :=
        % (-viscosity)*(4*b[w][2,p]-3*b[w][1,p]-b[w][3,p])/(2*zinterval) = Viscositeit[w]*(1/(.31e-1+(p-1)*rinterval)*(1*b[w][1,p+1]-b[w][1,p-1])/(2*rinterval)
        % -b[w][1,p]/((.31e-1+(p-1)*rinterval)^2)+(b[w][1,p+1]-2*b[w][1,p]+b[w][1,p-1])/(rinterval^2)) end do end do;
        
%         for p=2:S-2
%             
%             A(ax*ay+(p-1)*bx+1,ax*ay+(p-1)*bx+1)=-3*viscosity/(2*zinterval)+(Viscositeit(v))*(-1)/((.31e-1+(p-1)*rinterval)^2)-2*(Viscositeit(v))/(rinterval^2); %a[w][1,p]
%             A(ax*ay+(p-1)*bx+1,ax*ay+(p-1)*bx+2)=4*viscosity/(2*zinterval);% a[w][2,p]
%             A(ax*ay+(p-1)*bx+1,ax*ay+(p-1)*bx+3)=-1*viscosity/(2*zinterval);% a[w][3,p]
%             A(ax*ay+(p-1)*bx+1,ax*ay+(p)*bx+1)=(Viscositeit(v))*1/(.31e-1+(p-1)*rinterval)/(2*rinterval)+(Viscositeit(v))/(rinterval^2);% a[w][1,p+1]
%             A(ax*ay+(p-1)*bx+1,ax*ay+(p-2)*bx+1)=-(Viscositeit(v))*1/(.31e-1+(p-1)*rinterval)/(2*rinterval)+(Viscositeit(v))/(rinterval^2);% a[w][1,p-1]
%         end
        
        % for p from 2 to S-2 do eqnn[1,p] := 
        % (-viscositylower)*(4*b[2,p]-3*b[1,p]-b[3,p])/(2*zinterval)+(-viscosityupper)*(4*bb[2,p+4]-3*bb[1,p+4]-bb[3,p+4])/(2*zinterval) = 
        % X*(1/(.31e-1+(p-1)*rinterval)*(1*b[1,p+1]-b[1,p-1])/(2*rinterval)-b[1,p]/((.31e-1+(p-1)*rinterval)^2)+(b[1,p+1]-2*b[1,p]+b[1,p-1])/(rinterval^2)) end do;
        
        for p=2:S-2
            
            A(ax*ay+(p-1)*bx+1,ax*ay+(p-1)*bx+1)=-3*viscositylower/(2*zinterval)+(Viscositeit(v))*(-1)/((.31e-1+(p-1)*rinterval)^2)-2*(Viscositeit(v))/(rinterval^2); %b[w][1,p]
            A(ax*ay+(p-1)*bx+1,ax*ay+(p-1)*bx+2)=4*viscositylower/(2*zinterval);% b[w][2,p]
            A(ax*ay+(p-1)*bx+1,ax*ay+(p-1)*bx+3)=-1*viscositylower/(2*zinterval);% b[w][3,p]
            A(ax*ay+(p-1)*bx+1,ax*ay+(p)*bx+1)=(Viscositeit(v))*1/(.31e-1+(p-1)*rinterval)/(2*rinterval)+(Viscositeit(v))/(rinterval^2);% b[w][1,p+1]
            A(ax*ay+(p-1)*bx+1,ax*ay+(p-2)*bx+1)=-(Viscositeit(v))*1/(.31e-1+(p-1)*rinterval)/(2*rinterval)+(Viscositeit(v))/(rinterval^2);% b[w][1,p-1]
            A(ax*ay+(p-1)*bx+1,ax*ay+bx*by+aax*aay+(p+4-1)*bbx+1)=-3*viscosityupper/(2*zinterval); % bb[1,p+4];
            A(ax*ay+(p-1)*bx+1,ax*ay+bx*by+aax*aay+(p+4-1)*bbx+2)=4*viscosityupper/(2*zinterval); % bb[2,p+4];
            A(ax*ay+(p-1)*bx+1,ax*ay+bx*by+aax*aay+(p+4-1)*bbx+3)=-1*viscosityupper/(2*zinterval); % bb[3,p+4];
        end
        
        % for c from 4 to J+1 do eqnnnn[1,c]:=a[1,c]=aa[1,c] end do;
        
        for c=4:J+1
            
            A(ax*ay+bx*by+(c-1)*aax+1,ax*ay+bx*by+(c-1)*aax+1)=1;
            A(ax*ay+bx*by+(c-1)*aax+1,(c-1)*ax+1)=-1;
        
        end
        
        % for d from 1 to S-2 do eqnnnnn[1,d]:=b[1,d]=bb[1,d+4] end do;
        
        for d=1:S-2
            
            A(ax*ay+bx*by+aax*aay+(d+4-1)*bbx+1,ax*ay+bx*by+aax*aay+(d+4-1)*bbx+1)=1;
            A(ax*ay+bx*by+aax*aay+(d+4-1)*bbx+1,ax*ay+(d-1)*bx+1)=-1;
            
            
        %ax*ay+bx*by+(c-1)*aax+1
        %check=find(A(ax*ay+bx*by+aax*aay+(d+4-1)*bbx+1,:)~=0)
        %b(ax*ay+bx*by+(c-1)*aax+1)
        
        end
                 
        x=A\b;
        y=x;

        % Results[h,i]:=eval(a[h,i],sol)
        
        for h=1:ax
            
            for i=1:ay
                
                Results(h,i)=x(h+(i-1)*ax);
                
            end
        end
        
        % Resultaat[h,i]:=eval(b[h,i],sol)
        
        for h=1:bx
            
            for i=1:by
                
                Resultaat(h,i)=x(ax*ay+h+(i-1)*bx);
                
            end
        end
        % ResultsResults[h,i]:=eval(aa[h,i],sol)
        
        for h=1:aax
            
            for i=1:aay
                
                ResultsResults(h,i)=x(ax*ay+bx*by+h+(i-1)*aax);
                
            end
        end
        % ResultaatResultaat[h,i]:=eval(bb[h,i],sol)
        
        for h=1:bbx
            
            for i=1:bby
                
                ResultaatResultaat(h,i)=x(ax*ay+bx*by+aax*aay+h+(i-1)*bbx);
                
            end
        end
        
        
            
        interfasetorquebuiten = 2*3.141592654*.355e-1*Viscositeit(v)*.355e-1*.355e-1*(3*Results(1,3)/.355e-1-4*Results(1,4)/.3575e-1+1*Results(1,5)/.36e-1)/(2*rinterval);
        interfasetorquebinnen = 2*3.141592654*.345e-1*Viscositeit(v)*.345e-1*.345e-1*(3*Resultaat(1,15)/.345e-1-4*Resultaat(1, 14)/.3425e-1+1*Resultaat(1,13)/.34e-1)/(2*rinterval);
        
        interfasetotaltorque=interfasetorquebinnen+interfasetorquebuiten;
        
        subfasetorquebuitenlower = viscositylower*250*10^(-6)/2*((3*Results(1,3)-4*Results(1,4)+Results(1,5)+3*Results(1,3)-4*Results(2,3)+Results(3,3))*2*3.141592654*.355e-1^2/(2*250*10^(-6))+2*(3*Results(2,2)-4*Results(2,3)+Results(2,4)+3*Results(2,2)-4*Results(3,2)+Results(4,2))*2*3.141592654*.3525e-1^2/(2*250*10^(-6))+(3*Results(3,1)-4*Results(3,2)+Results(3,3)+3*Results(3,1)-4*Results(4,1)+Results(5,1))*2*3.141592654*.35e-1^2/(2*250*10^(-6)));
        subfasetorquebinnenlower = viscositylower*250*10^(-6)/2*((3*Resultaat(1,15)-4*Resultaat(1,14)+Resultaat(1,13)+3*Resultaat(1,15)-4*Resultaat(2,15)+Resultaat(3,15))*2*3.141592654*.345e-1^2/(2*250*10^(-6))+2*(3*Resultaat(2,16)-4*Resultaat(2,15)+Resultaat(2,14)+3*Resultaat(2,16)-4*Resultaat(3,16)+Resultaat(4,16))*2*3.141592654*.3475e-1^2/(2*250*10^(-6))+(3*Resultaat(3,17)-4*Resultaat(3,16)+Resultaat(3,15)+3*Resultaat(3,17)-4*Resultaat(4,17)+Resultaat(5,17))*2*3.141592654*.35e-1^2/(2*250*10^(-6)));
              
        subfasetorquelower = subfasetorquebuitenlower+subfasetorquebinnenlower;
        
        subfasetorquebuitenupper = viscosityupper*250*10^(-6)/2*((3*ResultsResults(1,3)-4*ResultsResults(1,4)+ResultsResults(1,5)+3*ResultsResults(1,3)-4*ResultsResults(2,3)+ResultsResults(3,3))*2*3.141592654*.355e-1^2/(2*250*10^(-6))+2*(3*ResultsResults(2,2)-4*ResultsResults(2,3)+ResultsResults(2,4)+3*ResultsResults(2,2)-4*ResultsResults(3,2)+ResultsResults(4,2))*2*3.141592654*.3525e-1^2/(2*250*10^(-6))+(3*ResultsResults(3,1)-4*ResultsResults(3,2)+ResultsResults(3,3)+3*ResultsResults(3,1)-4*ResultsResults(4,1)+ResultsResults(5,1))*2*3.141592654*.35e-1^2/(2*250*10^(-6)));
        subfasetorquebinnenupper = viscosityupper*250*10^(-6)/2*((3*ResultaatResultaat(1,19)-4*ResultaatResultaat(1,18)+ResultaatResultaat(1,17)+3*ResultaatResultaat(1,19)-4*ResultaatResultaat(2,19)+ResultaatResultaat(3,19))*2*3.141592654*.345e-1^2/(2*250*10^(-6))+2*(3*ResultaatResultaat(2,20)-4*ResultaatResultaat(2,19)+ResultaatResultaat(2,18)+3*ResultaatResultaat(2,20)-4*ResultaatResultaat(3,20)+ResultaatResultaat(4,20))*2*3.141592654*.3475e-1^2/(2*250*10^(-6))+(3*ResultaatResultaat(3,21)-4*ResultaatResultaat(3,20)+ResultaatResultaat(3,19)+3*ResultaatResultaat(3,21)-4*ResultaatResultaat(4,21)+ResultaatResultaat(5,21))*2*3.141592654*.35e-1^2/(2*250*10^(-6)));
        
        subfasetorqueupper = (subfasetorquebuitenupper+subfasetorquebinnenupper);
        subfasetotaltorque=subfasetorquelower+subfasetorquelower;
        torquetotaal(w)=interfasetotaltorque+subfasetotaltorque;
          
        if (abs(torquetotaal(w))>abs(softwaretorque))
            
            oud=Viscositeit(v);
            nieuw=((abs(softwaretorque))/(abs(torquetotaal(w))))*Viscositeit(v);
            
            convertext=num2str(abs((nieuw-oud)/oud));
            set(handles.convergentietext,'String',convertext);
            pause(1)
            
            if abs((nieuw-oud)/oud) < 0.0001 | w==maxaantaliteratiestappen
            
                convergentie=1;
                if w==maxaantaliteratiestappen
                status=0;
                end
                
                if abs((nieuw-oud)/oud) < 0.0001
                set(handles.convergentietext,'String','Yes!');
                end
            end
            
            Viscositeit(v)=((abs(softwaretorque))/(abs(torquetotaal(w))))*Viscositeit(v);
        
        else
            oud=Viscositeit(v);
            nieuw=((abs(torquetotaal(w)))/(abs(softwaretorque)))*Viscositeit(v);
            
            convertext=num2str(abs((nieuw-oud)/oud));
            set(handles.convergentietext,'String',convertext);
            pause(1)
            
            if abs((nieuw-oud)/oud) < 0.0001 | w==maxaantaliteratiestappen
                if w==maxaantaliteratiestappen
                status(v)=0;
                end
                convergentie=1;
                
                if abs((nieuw-oud)/oud) < 0.0001
                set(handles.convergentietext,'String','Yes!');
                end
            end

            Viscositeit(v)=((abs(torquetotaal(w)))/(abs(softwaretorque)))*Viscositeit(v);
        
        end 
        
        w=w+1;
    end
end

visc=Viscositeit;

toc        
    