function [visc,elast,status] = DWRLowerPhase_Osc_BG(Beginviscositeit,Beginelasticiteit,Softwaretorque,frequency,Density,Viscosity,angularamplitudeglobaal,handles,geometrieselectie)
% Matlab code om data van double wall ring te corrigeren voor
% subfase-contributies. Enkel met lower phase.

% Here you need to give in all you datapoints
tic

format long g
% Beginviscositeit=[1];
% Beginelasticiteit=[1];
% Softwaretorque=[.7874208225e-8+.9446795505e-8*i];
% frequency=[1];
% density=1000;
% viscosity=0.001;
% angularamplitude=[0.00114];

% parameters that remain constant, DON'T CHANGE



if geometrieselectie==1

    % Dimensions normal DWR (Big regular or TA ring)

    J=18;
    S=16;
    K=40;
    maxaantaliteratiestappen=10;
    rinterval=0.0045/J; %(250e-6)
    zinterval=0.01/K;   %(250e-6) 
    


    Ro1=0.035;      % middle ring radius
    Ro2=0.03525;    % (Ro1+Ro2) / 2
    Ro3=0.0355;     % outer ring radius
 
    Ri1=0.031;      % inner cup radius
    Ri17=0.0345;    % inner ring radius
    Ri18=0.03475;   % (Ri17+Ri19) / 2
    Ri19=0.035;     % middle ring radius = Ro1
 
elseif geometrieselectie==2 
 
    % Dimensions Midsize Ring

    J=22;
    S=18;
    K=32;
    maxaantaliteratiestappen=10;
    rinterval=0.005/J;  %(250e-6)
    zinterval=0.008/K;  %(250e-6)
    

    Ro1=0.024;      % middle ring radius
    Ro2=0.02425;    % (Ro1+Ro2) / 2
    Ro3=0.0245;     % outer ring radius
    
    Ri1=0.0195;     % inner cup radius
    Ri17=0.0235;    % inner ring radius
    Ri18=0.02375;   % (Ri17+Ri19) / 2
    Ri19=0.024;     % middle ring radius = Ro1
    
    
    elseif geometrieselectie==3
 
    % Dimensions Baby Ring

    J=22; % this and the following parameters are just copied from above
    S=18;
    K=32;
    maxaantaliteratiestappen=10;
    rinterval=0.005/J;  %(250e-6)
    zinterval=0.008/K;  %(250e-6)
    

    Ro1=0.0175;     % middle ring radius
    Ro2=0.01775;    % (Ro1+Ro2) / 2
    Ro3=0.018;      % outer ring radius
    
    Ri1=0.01425;    % inner cup radius
    Ri17=0.017;     % inner ring radius
    Ri18=0.01725;   % (Ri17+Ri19) / 2
    Ri19=0.0175;    % middle ring radius = Ro1

 
end 

 
convergentie=0;
status=1; 
ax=K+1;
ay=J+1;
bx=K+1;
by=S+1;


for v=1:length(Beginviscositeit)            % run over all datapoints
    
    pause(3)
    set(handles.convergentietext,'String','No');
    c=num2str(v);
    set(handles.datapoint,'String',c);
    pause(2)
    softwaretorque=Softwaretorque(v);
    density=Density(v);
    viscosity=Viscosity(v);
    Viscositeit(v)=Beginviscositeit(v);
    Elasticiteit(v)=Beginelasticiteit(v);
    angularamplitude(v)=angularamplitudeglobaal(v);
    
    w=1;
    
    status(v)=1;
    convergentie=0;
    
    while convergentie==0        % Iterate
        
        % Matrix with number of columns and rows equal to the total number
        % of points. In this way the differential equations can be solved
        % by linearization. Each row or column contains data concerting one
        % single point (r,z).
        A = eye(ax*ay+bx*by);
        
        
        % Boundary conditions (b)
        b = zeros(ax*ay+bx*by,1);
        
        
        % b(Points lying in or on the surface of the DWR geometry)=r-value
        % outer gap, points inside the geometry, r-postions
        b(1)=Ro1;
        b(2)=Ro1;
        b(3)=Ro1;
        b(ax+1)=Ro2;
        b(ax+2)=Ro2;
        b(2*ax+1)=Ro3;
        
        
        %inner gap, points inside the geometry, r-postions
        b(ax*ay+S*bx+1)=Ri19;
        b(ax*ay+S*bx+2)=Ri19;
        b(ax*ay+S*bx+3)=Ri19;
        b(ax*ay+(S-1)*bx+1)=Ri18;
        b(ax*ay+(S-2)*bx+1)=Ri17;
        b(ax*ay+(S-1)*bx+2)=Ri18;
        
        
        
        % b(Points lying on the cup walls or bottom) = velocity zero
        b(J*ax+1:J*ax+ax)=0;
        b(ax*ay+1:ax*ay+bx)=0;
        
        b(ax:ax:ax*ay)=0;
        b(ax*ay+bx:bx:ax*ay+bx*by)=0;
        
        % Equations
        % In the following section all A-values are calculated and inserted
        % in the matrix. This differs depending on the position close to
        % the boundary or not. In general A is subdivided into 10 sections.
        
% 1             for p from 3 to J do eqn[w][2,p] := I*density*frequency*a[w][2,p] = viscosity*(1/(.35e-1+(p-1)*rinterval)*(a[w][2,p+1]-a[w][2,p-1])/(2*rinterval)
%              -a[w][2,p]/((.35e-1+(p-1)*rinterval)^2)
%              +(a[w][2,p+1]-2*a[w][2,p]+a[w][2,p-1])/(rinterval^2)
%              +(a[w][3,p]-2*a[w][2,p]+a[w][1,p])/(zinterval^2)) end do end do;
%
        
        for p=3:J
            
            A((p-1)*ax+2,(p-1)*ax+2)=-i*density*frequency(v)/viscosity-1/((Ro1+(p-1)*rinterval)^2)-2/(rinterval^2)-2/(zinterval^2);   % a[w][2,p]
            A((p-1)*ax+2,(p)*ax+2)=(1/(Ro1+(p-1)*rinterval))/(2*rinterval)+1/(rinterval^2);                     % a[w][2,p+1]
            A((p-1)*ax+2,(p-2)*ax+2)=-1/(Ro1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);                  % a[w][2,p-1]
            A((p-1)*ax+2,(p-1)*ax+3)=1/(zinterval^2);                        % a[w][3,p]
            A((p-1)*ax+2,(p-1)*ax+1)=1/(zinterval^2);                        % a[w][1,p]
        end    
            
% 2              for p from 2 to S-1 do eqnn[w][2,p] := I*density*frequency*b[w][2,p] = 
%               viscosity*(1/(.31e-1+(p-1)*rinterval)*(b[w][2,p+1]-b[w][2,p-1])/(2*rinterval)
%               -b[w][2,p]/((.31e-1+(p-1)*rinterval)^2)+(b[w][2,p+1]-2*b[w][2,p]+b[w][2,p-1])/(rinterval^2)+
%               (b[w][3,p]-2*b[w][2,p]+b[w][1,p])/(zinterval^2)) end do end do;

        for p=2:S-1
            
            A(ax*ay+(p-1)*bx+2,ax*ay+(p-1)*bx+2)=-i*density*frequency(v)/viscosity-1/((Ri1+(p-1)*rinterval)^2)-2/(rinterval^2)-2/(zinterval^2);% b[w][2,p]
            A(ax*ay+(p-1)*bx+2,ax*ay+(p)*bx+2)=1/(Ri1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);     % b[w][2,p+1]
            A(ax*ay+(p-1)*bx+2,ax*ay+(p-2)*bx+2)=-1/(Ri1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);     % b[w][2,p-1]
            A(ax*ay+(p-1)*bx+2,ax*ay+(p-1)*bx+3)=1/(zinterval^2); % b[w][3,p]
            A(ax*ay+(p-1)*bx+2,ax*ay+(p-1)*bx+1)=1/(zinterval^2); % b[w][1,p]
        end   
%  3      
%                 for p from 2 to J do eqn[w][3,p] := I*density*frequency*a[w][3,p] = 
%                 viscosity*(1/(.35e-1+(p-1)*rinterval)*(a[w][3,p+1]-a[w][3,p-1])/(2*rinterval)-a[w][3,p]/((.35e-1+(p-1)*rinterval)^2)
%                 +(a[w][3,p+1]-2*a[w][3,p]+a[w][3,p-1])/(rinterval^2)+(a[w][4,p]-2*a[w][3,p]+a[w][2,p])/(zinterval^2)) end do end do;

        for p=2:J
            
            A((p-1)*ax+3,(p-1)*ax+2+1)=-i*density*frequency(v)/viscosity-1/((Ro1+(p-1)*rinterval)^2)-2/(rinterval^2)-2/(zinterval^2);% a[w][3,p]
            A((p-1)*ax+3,(p)*ax+2+1)=1/(Ro1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);   % a[w][3,p+1]
            A((p-1)*ax+3,(p-2)*ax+2+1)=-1/(Ro1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2); % a[w][3,p-1]
            A((p-1)*ax+3,(p-1)*ax+3+1)=1/(zinterval^2);% a[w][4,p]
            A((p-1)*ax+3,(p-1)*ax+1+1)=1/(zinterval^2);% a[w][2,p]
        end
%  4                  for p from 2 to S do eqnn[w][3,p] := I*density*frequency*b[w][3,p] = 
%                    viscosity*(1/(.31e-1+(p-1)*rinterval)*(b[w][3,p+1]-b[w][3,p-1])/(2*rinterval)-b[w][3,p]/(((.31e-1+(p-1)*rinterval)^2))+
%                    (b[w][3,p+1]-2*b[w][3,p]+b[w][3,p-1])/(rinterval^2)+(b[w][4,p]-2*b[w][3,p]+b[w][2,p])/(zinterval^2)) end do end do;   
       
        for p=2:S
            
            A(ax*ay+(p-1)*bx+3,ax*ay+(p-1)*bx+2+1)=-i*density*frequency(v)/viscosity-1/((Ri1+(p-1)*rinterval)^2)-2/(rinterval^2)-2/(zinterval^2);% b[w][3,p]
            A(ax*ay+(p-1)*bx+3,ax*ay+(p)*bx+2+1)=1/(Ri1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);     % b[w][3,p+1]
            A(ax*ay+(p-1)*bx+3,ax*ay+(p-2)*bx+2+1)=-1/(Ri1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);     % b[w][3,p-1]
            A(ax*ay+(p-1)*bx+3,ax*ay+(p-1)*bx+3+1)=1/(zinterval^2); % b[w][4,p]
            A(ax*ay+(p-1)*bx+3,ax*ay+(p-1)*bx+1+1)=1/(zinterval^2); % b[w][1,p]
        end    
% 5                   for p from 2 to J do for m from 4 to K do eqn[w][m,p] := I*density*frequency*a[w][m,p] = 
%                     viscosity*(1/(.35e-1+(p-1)*rinterval)*(a[w][m,p+1]-a[w][m,p-1])/(2*rinterval)-a[w][m,p]/((.35e-1+(p-1)*rinterval)^2)+
%                     (a[w][m,p+1]-2*a[w][m,p]+a[w][m,p-1])/(rinterval^2)+(
%                     a[w][m+1,p]-2*a[w][m,p]+a[w][m-1,p])/(zinterval^2)) end do end do end do;

        for p=2:J
            
            for m=4:K
                
                A((p-1)*ax+m,(p-1)*ax+m)=-i*density*frequency(v)/viscosity-1/((Ro1+(p-1)*rinterval)^2)-2/(rinterval^2)-2/(zinterval^2);   % a[w][m,p]
                A((p-1)*ax+m,(p)*ax+m)=1/(Ro1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);                     % a[w][m,p+1]
                A((p-1)*ax+m,(p-2)*ax+m)=-1/(Ro1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);                  % a[w][m,p-1]
                A((p-1)*ax+m,(p-1)*ax+m+1)=1/(zinterval^2);                        % a[w][m+1,p]
                A((p-1)*ax+m,(p-1)*ax+m-1)=1/(zinterval^2);                        % a[w][m-1,p]
            end
        end
        
%  6       for p from 2 to S do for m from 4 to K do eqnn[w][m,p] := I*density*frequency*b[w][m,p] = 
%         viscosity*(1/(.31e-1+(p-1)*rinterval)*(b[w][m,p+1]-b[w][m,p-1])/(2*rinterval)-b[w][m,p]/((.31e-1+(p-1)*rinterval)^2)+
%         (b[w][m,p+1]-2*b[w][m,p]+b[w][m,p-1])/(rinterval^2)+(b[w][m+1,p]-2*b[w][m,p]+b[w][m-1,p])/(zinterval^2)) end do end do end do;
        
        
        for p=2:S
            
            for m=4:K
                
                A(ax*ay+(p-1)*bx+m,ax*ay+(p-1)*bx+m)=-i*density*frequency(v)/viscosity-1/((Ri1+(p-1)*rinterval)^2)-2/(rinterval^2)-2/(zinterval^2);% b[w][m,p]
                A(ax*ay+(p-1)*bx+m,ax*ay+(p)*bx+m)=1/(Ri1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);     % b[w][m,p+1]
                A(ax*ay+(p-1)*bx+m,ax*ay+(p-2)*bx+m)=-1/(Ri1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);     % b[w][m,p-1]
                A(ax*ay+(p-1)*bx+m,ax*ay+(p-1)*bx+m+1)=1/(zinterval^2); % b[w][m+1,p]
                A(ax*ay+(p-1)*bx+m,ax*ay+(p-1)*bx+m-1)=1/(zinterval^2); % b[w][m-1,p]
            end
        end
        
%  7       for w from 1 to aantaliteratiestappen do for m from 4 to K do eqnnn[w][m,1] := b[w][m, 17] = a[w][m,1] end do end do; 

        for m=4:K
            
            A(ax*ay+S*bx+m,m)=1;
            A(ax*ay+S*bx+m,ax*ay+S*bx+m)=-1;
        end
        
% 8            for m from 4 to K do eqn[w][m,1] := I*density*frequency*a[w][m,1] =
%             viscosity*(1/.35e-1*(a[w][m,2]-b[w][m,S])/(2*rinterval)-a[w][m,1]/(.35e-1^2)+(a[w][m,2]-2*a[w][m,1]
%             +b[w][m,S])/(rinterval^2)+(a[w][m+1,1]-2*a[w][m,1]+a[w][m-1,1])/(zinterval^2)) end do end do;
                
        for m=4:K
            
            A(m,m)=-i*density*frequency(v)/viscosity-1/(Ro1^2)-2/(rinterval^2)-2/(zinterval^2);      % a[w][m,1]
            A(m,ax+m)=(1/(Ro1))/(2*rinterval)+1/(rinterval^2);            % a[w][m,2]
            A(m,ax*ay+(S-1)*bx+m)=-(1/Ro1)/(2*rinterval)+1/(rinterval^2); % b[w][m,S]
            A(m,m+1)=1/(zinterval^2);% a[w][m+1,1]
            A(m,m-1)=1/(zinterval^2);% a[w][m-1,1]
        end
        
%  9       for p from 4 to J do eqn[w][1,p] := -viscosity*(4*a[w][2,p]-3*a[w][1,p]-a[w][3,p])/(2*zinterval) = 
%         (Viscositeit[w,v]-I*Elasticiteit[w,v])*(1/(.35e-1+(p-1)*rinterval)*(a[w][1,p+1]-a[w][1,p-1])/(2*rinterval)
%         -a[w][1,p]/((.35e-1+(p-1)*rinterval)^2)+(a[w][1,p+1]-2*a[w][1,p]+a[w][1,p-1])/(rinterval^2)) end do end do;

        for p=4:J
            
            A((p-1)*ax+1,(p-1)*ax+1)=-3*viscosity/(2*zinterval)+(Viscositeit(v)-i*Elasticiteit(v))*(-1)/((Ro1+(p-1)*rinterval)^2)-2*(Viscositeit(v)-i*Elasticiteit(v))/(rinterval^2); %a[w][1,p]
            A((p-1)*ax+1,(p-1)*ax+2)=4*viscosity/(2*zinterval);% a[w][2,p]
            A((p-1)*ax+1,(p-1)*ax+3)=-1*viscosity/(2*zinterval);% a[w][3,p]
            A((p-1)*ax+1,(p)*ax+1)=(Viscositeit(v)-i*Elasticiteit(v))*1/(Ro1+(p-1)*rinterval)/(2*rinterval)+(Viscositeit(v)-i*Elasticiteit(v))/(rinterval^2);% a[w][1,p+1]
            A((p-1)*ax+1,(p-2)*ax+1)=-(Viscositeit(v)-i*Elasticiteit(v))*1/(Ro1+(p-1)*rinterval)/(2*rinterval)+(Viscositeit(v)-i*Elasticiteit(v))/(rinterval^2);% a[w][1,p-1]
        end
        
% 10        for p from 2 to S-2 do eqnn[w][1,p] := -viscosity*(4*b[w][2,p]-3*b[w][1,p]-b[w][3,p])/(2*zinterval) = 
%         (Viscositeit[w,v]-I*Elasticiteit[w,v])*(1/(.31e-1+(p-1)*rinterval)*(b[w][1,p+1]-b[w][1,p-1])/(2*rinterval)
%         -b[w][1,p]/((.31e-1+(p-1)*rinterval)^2)+(b[w][1,p+1]-2*b[w][1,p]+b[w][1,p-1])/(rinterval^2)) end do end do;
        
        for p=2:S-2
            
            A(ax*ay+(p-1)*bx+1,ax*ay+(p-1)*bx+1)=-3*viscosity/(2*zinterval)+(Viscositeit(v)-i*Elasticiteit(v))*(-1)/((Ri1+(p-1)*rinterval)^2)-2*(Viscositeit(v)-i*Elasticiteit(v))/(rinterval^2); %a[w][1,p]
            A(ax*ay+(p-1)*bx+1,ax*ay+(p-1)*bx+2)=4*viscosity/(2*zinterval);% a[w][2,p]
            A(ax*ay+(p-1)*bx+1,ax*ay+(p-1)*bx+3)=-1*viscosity/(2*zinterval);% a[w][3,p]
            A(ax*ay+(p-1)*bx+1,ax*ay+(p)*bx+1)=(Viscositeit(v)-i*Elasticiteit(v))*1/(Ri1+(p-1)*rinterval)/(2*rinterval)+(Viscositeit(v)-i*Elasticiteit(v))/(rinterval^2);% a[w][1,p+1]
            A(ax*ay+(p-1)*bx+1,ax*ay+(p-2)*bx+1)=-(Viscositeit(v)-i*Elasticiteit(v))*1/(Ri1+(p-1)*rinterval)/(2*rinterval)+(Viscositeit(v)-i*Elasticiteit(v))/(rinterval^2);% a[w][1,p-1]
        end
        
        
        % From the differential equations, x is calculated.
        % X contains for every point the velocity in tangential direction
        
        
        
        x=A\b;
        %x=linsolve(A,b);
        y=x;
        
        
        % Berekening werkelijke torque nodig voor dit snelheidsveld
        
        TInterfaseBuiten=(angularamplitude(v)*i*2*pi*Ro3*(Viscositeit(v)-Elasticiteit(v)*i)*Ro3*Ro3*((3*x(1+2*ax)/Ro3-4*x(1+3*ax)/(Ro3+rinterval)+1*x(1+4*ax)/(Ro3+2*rinterval))/(2*rinterval))*frequency(v));
        TInterfaseBinnen=(angularamplitude(v)*i*2*pi*Ri17*(Viscositeit(v)-Elasticiteit(v)*i)*Ri17*Ri17*(3*y(ax*ay+1+(S-2)*bx)/Ri17-4*y(ax*ay+1+(S-3)*bx)/(Ri17-rinterval)+1*y(ax*ay+1+(S-4)*bx)/(Ri17-2*rinterval))/(2*rinterval)*frequency(v));
        
        T3=(angularamplitude(v)*i*frequency(v)*viscosity*zinterval*((3*x(1+2*ax)-4*x(1+3*ax)+x(1+4*ax)+3*x(1+2*ax)-4*x(2+2*ax)+x(3+2*ax))*2*pi*Ro3^2/(2*zinterval)+2*(3*x(2+1*ax)-4*x(2+2*ax)+x(2+3*ax)+3*x(2+1*ax)-4*x(3+1*ax)+x(4+1*ax))*2*pi*Ro2^2/(2*zinterval)+(3*x(3+0*ax)-4*x(3+1*ax)+x(3+2*ax)+3*x(3+0*ax)-4*x(4+0*ax)+x(5+0*ax))*2*pi*Ro1^2/(2*zinterval))/2);
        T4=(angularamplitude(v)*i*frequency(v)*viscosity*zinterval*((3*y(ax*ay+1+(S-2)*bx)-4*y(ax*ay+1+(S-3)*bx)+y(ax*ay+1+(S-4)*bx)+3*y(ax*ay+1+(S-2)*bx)-4*y(ax*ay+2+(S-2)*bx)+y(ax*ay+3+(S-2)*bx))*2*pi*Ri17^2/(2*zinterval)+2*(3*y(ax*ay+2+(S-1)*bx)-4*y(ax*ay+2+(S-2)*bx)+y(ax*ay+2+(S-3)*bx)+3*y(ax*ay+2+(S-1)*bx)-4*y(ax*ay+3+(S-1)*bx)+y(ax*ay+4+(S-1)*bx))*2*pi*Ri18^2/(2*zinterval)+(3*y(ax*ay+3+S*bx)-4*y(ax*ay+3+(S-1)*bx)+y(ax*ay+3+(S-2)*bx)+3*y(ax*ay+3+S*bx)-4*y(ax*ay+4+S*bx)+y(ax*ay+5+S*bx))*2*pi*Ro1^2/(2*zinterval))/2);
 
        
        %Torque(w)=(angularamplitude(v)*i*2*pi*Ro3*(Viscositeit(v)-Elasticiteit(v)*i)*Ro3*Ro3*((3*x(1+2*ax)/Ro3-4*x(1+3*ax)/(Ro3+rinterval)+1*x(1+4*ax)/(Ro3+2*rinterval))/(2*rinterval))*frequency(v))+(angularamplitude(v)*i*2*pi*Ri17*(Viscositeit(v)-Elasticiteit(v)*i)*Ri17*Ri17*(3*y(ax*ay+1+(S-2)*bx)/Ri17-4*y(ax*ay+1+(S-3)*bx)/(Ri17-rinterval)+1*y(ax*ay+1+(S-4)*bx)/(Ri17-2*rinterval))/(2*rinterval)*frequency(v))+(angularamplitude(v)*i*frequency(v)*viscosity*zinterval*((3*x(1+2*ax)-4*x(1+3*ax)+x(1+4*ax)+3*x(1+2*ax)-4*x(2+2*ax)+x(3+2*ax))*2*pi*Ro3^2/(2*zinterval)+2*(3*x(2+1*ax)-4*x(2+2*ax)+x(2+3*ax)+3*x(2+1*ax)-4*x(3+1*ax)+x(4+1*ax))*2*pi*Ro2^2/(2*zinterval)+(3*x(3+0*ax)-4*x(3+1*ax)+x(3+2*ax)+3*x(3+0*ax)-4*x(4+0*ax)+x(5+0*ax))*2*pi*Ro1^2/(2*zinterval))/2)+(angularamplitude(v)*i*frequency(v)*viscosity*zinterval*((3*y(ax*ay+1+(S-2)*bx)-4*y(ax*ay+1+(S-3)*bx)+y(ax*ay+1+(S-4)*bx)+3*y(ax*ay+1+(S-2)*bx)-4*y(ax*ay+2+(S-2)*bx)+y(ax*ay+3+(S-2)*bx))*2*pi*Ri17^2/(2*zinterval)+2*(3*y(ax*ay+2+(S-1)*bx)-4*y(ax*ay+2+(S-2)*bx)+y(ax*ay+2+(S-3)*bx)+3*y(ax*ay+2+(S-1)*bx)-4*y(ax*ay+3+(S-1)*bx)+y(ax*ay+4+(S-1)*bx))*2*pi*Ri18^2/(2*zinterval)+(3*y(ax*ay+3+S*bx)-4*y(ax*ay+3+(S-1)*bx)+y(ax*ay+3+(S-2)*bx)+3*y(ax*ay+3+S*bx)-4*y(ax*ay+4+S*bx)+y(ax*ay+5+S*bx))*2*pi*Ro1^2/(2*zinterval))/2);
        
        Torque(w)=TInterfaseBuiten+TInterfaseBinnen+T3+T4;
        
        
        
        ReTorque(w)=real(Torque(w));
        imagTorque(w)=imag(Torque(w));
        
        oud=abs(Viscositeit(v)-Elasticiteit(v)*i);
        nieuw=abs((imag(softwaretorque)/imagTorque(w))*Viscositeit(v)-(real(softwaretorque)/ReTorque(w))*Elasticiteit(v)*i);
        
        convertext=num2str(abs((nieuw-oud)/oud));
        set(handles.convergentietext,'String',convertext);
        pause(1)
        
        if abs((nieuw-oud)/oud) < 0.01 | w==maxaantaliteratiestappen
            if w==maxaantaliteratiestappen
            status(v)=0;
            end
            convergentie=1;
            if abs((nieuw-oud)/oud) < 0.01
                set(handles.convergentietext,'String','Yes!');
            end
        end
        
        Viscositeit(v)=(imag(softwaretorque)/imagTorque(w))*Viscositeit(v);
        Elasticiteit(v)=(real(softwaretorque)/ReTorque(w))*Elasticiteit(v); 
        Viscositeit(v);
        Elasticiteit(v);
        
        w=w+1;
    end
end

visc=Viscositeit;
elast=Elasticiteit;
toc        
    