function [visc,status] = DWRLowerPhase_Shear(Beginviscositeit,Softwaretorque,Density,Viscosity,angularvelocityglobal,handles,geometrieselectie)
global datapoint
% Matlab code om data van double wall ring te corrigeren voor
% subfase-contributies. Enkel met lower phase.

% Here you need to give in all you datapoints
tic

format long g
% Beginviscositeit=[0.000102];
% Softwaretorque=[9.9263*10^(-6)];
% density=1000;
% viscosity=0.001;
% angularvelocity=[0.7197];

% parameters that remain constant, DON'T CHANGE

if geometrieselectie==1

    % Dimensions normal DWR

    J=18;
    S=16;
    K=40;
    maxaantaliteratiestappen=10;
    rinterval=0.0045/J; %(250e-6)
    zinterval=0.01/K;   %(250e-6) 
    


    Ro1=0.035;
    Ro2=0.03525;
    Ro3=0.0355;
    Ro4=0.03575;
    Ro5=0.036;
 
    Ri1=0.031;
    Ri15=0.034;
    Ri16=0.03425;
    Ri17=0.0345;
    Ri18=0.03475;
    Ri19=0.035;
 
elseif geometrieselectie==2 
 
    % Dimensions midsize DWR

    J=22;
    S=18;
    K=48;
    maxaantaliteratiestappen=10;
    rinterval=0.005/J;  %(250e-6)
    zinterval=0.012/K;  %(250e-6)
    

    Ro1=0.024;
    Ro2=0.02425;
    Ro3=0.0245;
    Ro4=0.02475;
    Ro5=0.025;
    
    Ri1=0.0195;
    Ri15=0.019;
    Ri16=0.01925;
    Ri17=0.0235;
    Ri18=0.02375;
    Ri19=0.024;
 
end 

ax=K+1;
ay=J+1;
bx=K+1;
by=S+1;

for v=1:length(Beginviscositeit)            % run over all datapoints
    
    pause(3)
    set(handles.convergentietext,'String','No');
    c=num2str(v);
    set(handles.datapoint,'String',c);
    pause(2)
    softwaretorque=Softwaretorque(v);
    Viscositeit(v)=Beginviscositeit(v);
    angularvelocity=angularvelocityglobal(v);
    density=Density(v);
    viscosity=Viscosity(v);
    
    w=1;
    status(v)=1;
    convergentie=0;
    
    while convergentie==0          % Iteration
        
        A = eye(ax*ay+bx*by);
        b = zeros(ax*ay+bx*by,1);
        
        % Boundary conditions        
        
        b(1)=Ro1*angularvelocity;
        b(2)=Ro1*angularvelocity;
        b(3)=Ro1*angularvelocity;
        b(ax+1)=Ro2*angularvelocity;
        b(2*ax+1)=Ro3*angularvelocity;
        b(ax+2)=Ro2*angularvelocity;
        
        b(ax*ay+S*bx+1)=Ri19*angularvelocity;
        b(ax*ay+S*bx+2)=Ri19*angularvelocity;
        b(ax*ay+S*bx+3)=Ri19*angularvelocity;
        b(ax*ay+(S-1)*bx+1)=Ri18*angularvelocity;
        b(ax*ay+(S-2)*bx+1)=Ri17*angularvelocity;
        b(ax*ay+(S-1)*bx+2)=Ri18*angularvelocity;
        
        b(J*ax+1:J*ax+ax)=0;
        b(ax*ay+1:ax*ay+bx)=0;
        
        b(ax:ax:ax*ay)=0;
        b(ax*ay+bx:bx:ax*ay+bx*by)=0;
        
        % Equations
        
        
        % for w to 5 do for p from 3 to J do eqn[w][2,p] := 
        % 0 = viscosity*(1/(Ro1+(p-1)*rinterval)*(a[w][2,p+1]-a[w][2,p-1])/(2*rinterval)-a[w][2,p]/((Ro1+(p-1)*rinterval)^2)+
        % (a[w][2,p+1]-2*a[w][2,p]+a[w][2,p-1])/(rinterval^2)+(a[w][3,p]-2*a[w][2,p]+a[w][1,p])/(zinterval^2)) end do end do;
          
        for p=3:J
            
            A((p-1)*ax+2,(p-1)*ax+2)=-1/((Ro1+(p-1)*rinterval)^2)-2/(rinterval^2)-2/(zinterval^2);   % a[w][2,p]
            A((p-1)*ax+2,(p)*ax+2)=1/(Ro1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);                     % a[w][2,p+1]
            A((p-1)*ax+2,(p-2)*ax+2)=-1/(Ro1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);                  % a[w][2,p-1]
            A((p-1)*ax+2,(p-1)*ax+3)=1/(zinterval^2);                        % a[w][3,p]
            A((p-1)*ax+2,(p-1)*ax+1)=1/(zinterval^2);                        % a[w][1,p]
        end    
            
        % for w to 5 do for p from 2 to S-1 do eqnn[w][2,p] := 
        % 0 = viscosity*(1/(Ri1+(p-1)*rinterval)*(b[w][2,p+1]-b[w][2,p-1])/(2*rinterval)-b[w][2,p]/((Ri1+(p-1)*rinterval)^2)+
        % (b[w][2,p+1]-2*b[w][2,p]+b[w][2,p-1])/(rinterval^2)+(b[w][3,p]-2*b[w][2,p]+b[w][1,p])/(zinterval^2)) end do end do;

        for p=2:S-1
            
            A(ax*ay+(p-1)*bx+2,ax*ay+(p-1)*bx+2)=-1/((Ri1+(p-1)*rinterval)^2)-2/(rinterval^2)-2/(zinterval^2);% b[w][2,p]
            A(ax*ay+(p-1)*bx+2,ax*ay+(p)*bx+2)=1/(Ri1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);     % b[w][2,p+1]
            A(ax*ay+(p-1)*bx+2,ax*ay+(p-2)*bx+2)=-1/(Ri1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);     % b[w][2,p-1]
            A(ax*ay+(p-1)*bx+2,ax*ay+(p-1)*bx+3)=1/(zinterval^2); % b[w][3,p]
            A(ax*ay+(p-1)*bx+2,ax*ay+(p-1)*bx+1)=1/(zinterval^2); % b[w][1,p]
        end   

        % for w from 1 to 5 do for p from 2 to J do eqn[w][3,p] := 
        % 0 = viscosity*(1/(Ro1+(p-1)*rinterval)*(a[w][3,p+1]-a[w][3,p-1])/(2*rinterval)-a[w][3,p]/((Ro1+(p-1)*rinterval)^2)+
        % (a[w][3,p+1]-2*a[w][3,p]+a[w][3,p-1])/(rinterval^2)+(a[w][4,p]-2*a[w][3,p]+a[w][2,p])/(zinterval^2)) end do end do;

        for p=2:J
            
            A((p-1)*ax+3,(p-1)*ax+2+1)=-1/((Ro1+(p-1)*rinterval)^2)-2/(rinterval^2)-2/(zinterval^2);% a[w][3,p]
            A((p-1)*ax+3,(p)*ax+2+1)=1/(Ro1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);   % a[w][3,p+1]
            A((p-1)*ax+3,(p-2)*ax+2+1)=-1/(Ro1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2); % a[w][3,p-1]
            A((p-1)*ax+3,(p-1)*ax+3+1)=1/(zinterval^2);% a[w][4,p]
            A((p-1)*ax+3,(p-1)*ax+1+1)=1/(zinterval^2);% a[w][2,p]
        end

        % for w to 5 do for p from 2 to S do eqnn[w][3,p] := 
        % 0 = viscosity*(1/(Ri1+(p-1)*rinterval)*(b[w][3,p+1]-b[w][3,p-1])/(2*rinterval)-b[w][3,p]/((Ri1+(p-1)*rinterval)^2)+
        % (b[w][3,p+1]-2*b[w][3,p]+b[w][3,p-1])/(rinterval^2)+(b[w][4,p]-2*b[w][3,p]+b[w][2,p])/(zinterval^2)) end do end do;
       
        for p=2:S
            
            A(ax*ay+(p-1)*bx+3,ax*ay+(p-1)*bx+2+1)=-1/((Ri1+(p-1)*rinterval)^2)-2/(rinterval^2)-2/(zinterval^2);% b[w][3,p]
            A(ax*ay+(p-1)*bx+3,ax*ay+(p)*bx+2+1)=1/(Ri1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);     % b[w][3,p+1]
            A(ax*ay+(p-1)*bx+3,ax*ay+(p-2)*bx+2+1)=-1/(Ri1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);     % b[w][3,p-1]
            A(ax*ay+(p-1)*bx+3,ax*ay+(p-1)*bx+3+1)=1/(zinterval^2); % b[w][4,p]
            A(ax*ay+(p-1)*bx+3,ax*ay+(p-1)*bx+1+1)=1/(zinterval^2); % b[w][1,p]
        end    

        % for w from 1 to 5 do for p from 2 to J do for m from 4 to K do
        % eqn[w][m,p] := 0 = viscosity*(1/(Ro1+(p-1)*rinterval)*(a[w][m,p+1]-a[w][m,p-1])/(2*rinterval)-a[w][m,p]/((Ro1+(p-1)*rinterval)^2)+
        % (a[w][m,p+1]-2*a[w][m,p]+a[w][m,p-1])/(rinterval^2)+(a[w][m+1,p]-2*a[w][m,p]+a[w][m-1,p])/(zinterval^2))end do end do end do;

        for p=2:J
            
            for m=4:K
                
                A((p-1)*ax+m,(p-1)*ax+m)=-1/((Ro1+(p-1)*rinterval)^2)-2/(rinterval^2)-2/(zinterval^2);   % a[w][m,p]
                A((p-1)*ax+m,(p)*ax+m)=1/(Ro1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);                     % a[w][m,p+1]
                A((p-1)*ax+m,(p-2)*ax+m)=-1/(Ro1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);                  % a[w][m,p-1]
                A((p-1)*ax+m,(p-1)*ax+m+1)=1/(zinterval^2);                        % a[w][m+1,p]
                A((p-1)*ax+m,(p-1)*ax+m-1)=1/(zinterval^2);                        % a[w][m-1,p]
            end
        end
        
        % for w to 5 do for p from 2 to S do for m from 4 to K do
        % eqnn[w][m,p] := 0 = viscosity*(1/(Ri1+(p-1)*rinterval)*(b[w][m,p+1]-b[w][m,p-1])/(2*rinterval)-b[w][m,p]/((Ri1+(p-1)*rinterval)^2)+
        % (b[w][m,p+1]-2*b[w][m,p]+b[w][m,p-1])/(rinterval^2)+(b[w][m+1,p]-2*b[w][m,p]+b[w][m-1,p])/(zinterval^2)) end do end do end do;
        
        
        for p=2:S
            
            for m=4:K
                
                A(ax*ay+(p-1)*bx+m,ax*ay+(p-1)*bx+m)=-1/((Ri1+(p-1)*rinterval)^2)-2/(rinterval^2)-2/(zinterval^2);% b[w][m,p]
                A(ax*ay+(p-1)*bx+m,ax*ay+(p)*bx+m)=1/(Ri1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);     % b[w][m,p+1]
                A(ax*ay+(p-1)*bx+m,ax*ay+(p-2)*bx+m)=-1/(Ri1+(p-1)*rinterval)/(2*rinterval)+1/(rinterval^2);     % b[w][m,p-1]
                A(ax*ay+(p-1)*bx+m,ax*ay+(p-1)*bx+m+1)=1/(zinterval^2); % b[w][m+1,p]
                A(ax*ay+(p-1)*bx+m,ax*ay+(p-1)*bx+m-1)=1/(zinterval^2); % b[w][m-1,p]
            end
        end
        
        % for w from 1 to aantaliteratiestappen do for m from 4 to K do eqnnn[w][m,1] := b[w][m, 17] = a[w][m,1] end do end do; 

        for m=4:K
            
            A(ax*ay+S*bx+m,m)=1;
            A(ax*ay+S*bx+m,ax*ay+S*bx+m)=-1;
        end
        
        % for w to 5 do for m from 4 to K do eqn[w][m,1] := 0 =
        % viscosity*(1/Ro1*(a[w][m,2]-b[w][m,S])/(2*rinterval)-a[w][m,1]/(Ro1^2)+(a[w][m,2]-2*a[w][m,1]+b[w][m,S])/(rinterval^2)+
        % (a[w][m+1,1]-2*a[w][m,1]+a[w][m-1,1])/(zinterval^2)) end do end do;
                
        for m=4:K
            
            A(m,m)=-1/(Ro1^2)-2/(rinterval^2)-2/(zinterval^2);      % a[w][m,1]
            A(m,ax+m)=(1/(Ro1))/(2*rinterval)+1/(rinterval^2);            % a[w][m,2]
            A(m,ax*ay+(S-1)*bx+m)=-(1/Ro1)/(2*rinterval)+1/(rinterval^2); % b[w][m,S]
            A(m,m+1)=1/(zinterval^2);% a[w][m+1,1]
            A(m,m-1)=1/(zinterval^2);% a[w][m-1,1]
        end

        % for w to 5 do for p from 4 to J do eqn[w][1,p] :=
        % (-viscosity)*(4*a[w][2,p]-3*a[w][1,p]-a[w][3,p])/(2*zinterval) = Viscositeit[w]*(1/(Ro1+(p-1)*rinterval)*(1*a[w][1,p+1]-a[w][1,p-1])/(2*rinterval)
        % -a[w][1,p]/((Ro1+(p-1)*rinterval)^2)+(a[w][1,p+1]-2*a[w][1,p]+a[w][1,p-1])/(rinterval^2)) end do end do;
        
        for p=4:J
            
            A((p-1)*ax+1,(p-1)*ax+1)=-3*viscosity/(2*zinterval)+(Viscositeit(v))*(-1)/((Ro1+(p-1)*rinterval)^2)-2*(Viscositeit(v))/(rinterval^2); %a[w][1,p]
            A((p-1)*ax+1,(p-1)*ax+2)=4*viscosity/(2*zinterval);% a[w][2,p]
            A((p-1)*ax+1,(p-1)*ax+3)=-1*viscosity/(2*zinterval);% a[w][3,p]
            A((p-1)*ax+1,(p)*ax+1)=(Viscositeit(v))*1/(Ro1+(p-1)*rinterval)/(2*rinterval)+(Viscositeit(v))/(rinterval^2);% a[w][1,p+1]
            A((p-1)*ax+1,(p-2)*ax+1)=-(Viscositeit(v))*1/(Ro1+(p-1)*rinterval)/(2*rinterval)+(Viscositeit(v))/(rinterval^2);% a[w][1,p-1]
        end
        
        % for w to 5 do for p from 2 to S-2 do eqnn[w][1,p] :=
        % (-viscosity)*(4*b[w][2,p]-3*b[w][1,p]-b[w][3,p])/(2*zinterval) = Viscositeit[w]*(1/(Ri1+(p-1)*rinterval)*(1*b[w][1,p+1]-b[w][1,p-1])/(2*rinterval)
        % -b[w][1,p]/((Ri1+(p-1)*rinterval)^2)+(b[w][1,p+1]-2*b[w][1,p]+b[w][1,p-1])/(rinterval^2)) end do end do;
        
        for p=2:S-2
            
            A(ax*ay+(p-1)*bx+1,ax*ay+(p-1)*bx+1)=-3*viscosity/(2*zinterval)+(Viscositeit(v))*(-1)/((Ri1+(p-1)*rinterval)^2)-2*(Viscositeit(v))/(rinterval^2); %a[w][1,p]
            A(ax*ay+(p-1)*bx+1,ax*ay+(p-1)*bx+2)=4*viscosity/(2*zinterval);% a[w][2,p]
            A(ax*ay+(p-1)*bx+1,ax*ay+(p-1)*bx+3)=-1*viscosity/(2*zinterval);% a[w][3,p]
            A(ax*ay+(p-1)*bx+1,ax*ay+(p)*bx+1)=(Viscositeit(v))*1/(Ri1+(p-1)*rinterval)/(2*rinterval)+(Viscositeit(v))/(rinterval^2);% a[w][1,p+1]
            A(ax*ay+(p-1)*bx+1,ax*ay+(p-2)*bx+1)=-(Viscositeit(v))*1/(Ri1+(p-1)*rinterval)/(2*rinterval)+(Viscositeit(v))/(rinterval^2);% a[w][1,p-1]
        end
        
        x=A\b;
        %x=linsolve(A,b);
        y=x;
 
        %Results=a
        %Resultaat=b 
        
        Torque(w)= 2*3.141592654*Ro3*Viscositeit(v)*Ro3*Ro3*(3*x(1+2*ax)/Ro3-4*x(1+3*ax)/Ro4+1*x(1+4*ax)/Ro5)/(2*rinterval)+2*3.141592654*Ri17*Viscositeit(v)*Ri17*Ri17*(3*y(ax*ay+1+(S-2)*bx)/Ri17-4*y(ax*ay+1+(S-3)*bx)/Ri16+1*y(ax*ay+1+(S-4)*bx)/Ri15)/(2*rinterval)+1*viscosity*250*10^(-6)/2*((3*x(1+2*ax)-4*x(1+3*ax)+x(1+4*ax)+3*x(1+2*ax)-4*x(2+2*ax)+x(3+2*ax))*2*3.141592654*Ro3^2/(2*250*10^(-6))+2*(3*x(2+ax)-4*x(2+2*ax)+x(2+3*ax)+3*x(2+ax)-4*x(3+ax)+x(4+ax))*2*3.141592654*Ro2^2/(2*250*10^(-6))+(3*x(3)-4*x(3+ax)+x(3+2*ax)+3*x(3)-4*x(4)+x(5))*2*3.141592654*Ro1^2/(2*250*10^(-6)))+viscosity*250*10^(-6)/2*((3*y(ax*ay+1+(S-2)*bx)-4*y(ax*ay+1+(S-3)*bx)+y(ax*ay+1+(S-4)*bx)+3*y(ax*ay+1+(S-2)*bx)-4*y(ax*ay+2+(S-2)*bx)+y(ax*ay+3+(S-2)*bx))*2*3.141592654*Ri17^2/(2*250*10^(-6))+2*(3*y(ax*ay+2+(S-1)*bx)-4*y(ax*ay+2+(S-2)*bx)+y(ax*ay+2+(S-3)*bx)+3*y(ax*ay+2+(S-1)*bx)-4*y(ax*ay+3+(S-1)*bx)+y(ax*ay+4+(S-1)*bx))*2*3.141592654*Ri18^2/(2*250*10^(-6))+(3*y(ax*ay+3+S*bx)-4*y(ax*ay+3+15*bx)+y(ax*ay+3+(S-2)*bx)+3*y(ax*ay+3+S*bx)-4*y(ax*ay+4+S*bx)+y(ax*ay+5+S*bx))*2*3.141592654*Ro1^2/(2*250*10^(-6))); 

        if (abs(Torque(w))>abs(softwaretorque))
            
            oud=Viscositeit(v);
            nieuw=((abs(softwaretorque))/(abs(Torque(w))))*Viscositeit(v);
            
            %abs((nieuw-oud)/oud)
            convertext=num2str((abs(nieuw-oud)/oud));
            set(handles.convergentietext,'String',convertext);
            pause(2)
            
            if abs((nieuw-oud)/oud) < 0.01 | w==maxaantaliteratiestappen
                if w==maxaantaliteratiestappen
                status=0;
                end
                convergentie=1; 
            
                if abs((nieuw-oud)/oud) < 0.01
                    set(handles.convergentietext,'String','Yes!');
                end
            end
            
            Viscositeit(v)=((abs(softwaretorque))/(abs(Torque(w))))*Viscositeit(v);
        
        else
            oud=Viscositeit(v);
            nieuw=((abs(Torque(w)))/(abs(softwaretorque)))*Viscositeit(v);
            
            %abs((nieuw-oud)/oud)
            convertext=num2str((abs(nieuw-oud)/oud));
            set(handles.convergentietext,'String',convertext);
            pause(2)
            
            if abs((nieuw-oud)/oud) < 0.01 | w==maxaantaliteratiestappen
                if w==maxaantaliteratiestappen
                status(v)=0;
                end
                
                if abs((nieuw-oud)/oud) < 0.01
                set(handles.convergentietext,'String','Yes!');
                end
                convergentie=1; 
            end

            Viscositeit(v)=((abs(Torque(w)))/(abs(softwaretorque)))*Viscositeit(v);
        
        end 
        
        w=w+1;
    end
end

visc=Viscositeit;

toc        
    